@@ -40,6 +40,61 @@ static const char rcsid[] = "$Id: sub-output.c,v 1.32 2003/03/19 12:33:56 simius
 #include <string.h>
 #include "sub.h"
 
+void
+show_c_wildcard_info_v4 (struct if_info *ifi)
+{
+	u_int32_t mask;
+	int bitcount;
+	int x;
+
+	mask = ifi->v4ad.n_haddr ^ 0xffffffff;
+	bitcount = 0;
+	for (x = 0; x < 32; x++) {
+		if ((mask >> x) & 1)
+			bitcount++;
+	}
+
+	printf ("[WILDCARD]\n");
+	printf ("Wildcard		- %s\n",
+		numtoquad (ifi->v4ad.n_haddr));
+	printf ("Network mask		- %s\n",
+		numtoquad (mask));
+	printf ("Network mask (bits)	- %d\n",
+		bitcount);
+	printf ("\n");
+/*
+	printf ("Host address		- %s\n", numtoquad (ifi->v4ad.n_haddr));
+	printf ("Host address (decimal)	- %u\n", ifi->v4ad.n_haddr);
+	printf ("Host address (hex)	- %X\n", ifi->v4ad.n_haddr);
+	printf ("Network address		- %s\n",
+		numtoquad (ifi->v4ad.n_naddr));
+	printf ("Network mask		- %s\n", numtoquad (ifi->v4ad.n_nmask));
+	printf ("Network mask (bits)	- %d\n", ifi->v4ad.n_nmaskbits);
+	printf ("Network mask (hex)	- %X\n", ifi->v4ad.n_nmask);
+	printf ("Broadcast address	- %s\n",
+		numtoquad (ifi->v4ad.n_broadcast));
+	printf ("Cisco wildcard		- %s\n",
+		numtoquad (ifi->v4ad.n_nmask ^ 0xffffffff));
+	if (!ifi->v4ad.n_nmask)
+		printf ("Addresses in network	- %u\n",
+			(ifi->v4ad.n_broadcast) - (ifi->v4ad.n_naddr));
+	else
+		printf ("Addresses in network	- %u\n",
+			(ifi->v4ad.n_broadcast) - (ifi->v4ad.n_naddr) + 1);
+	printf ("Network range		- %s - ", numtoquad (ifi->v4ad.n_naddr));
+	printf ("%s\n", numtoquad (ifi->v4ad.n_broadcast));
+	if (ifi->v4ad.n_naddr + 1 <= ifi->v4ad.n_broadcast - 1) {
+		printf ("Usable range		- %s - ",
+			numtoquad (ifi->v4ad.n_naddr + 1));
+		printf ("%s\n", numtoquad (ifi->v4ad.n_broadcast - 1));
+	}
+	printf ("\n");
+*/
+
+	return;
+}
+
+
 void
 show_split_networks_v4 (struct if_info *ifi, u_int32_t splitmask, int v4args, struct misc_args m_argv4)
 {
@@ -593,7 +648,7 @@ show_split_networks_v6 (struct if_info *ifi, struct sip_in6_addr splitmask, int
 
 		y = 0;
 		for (z = 0; z < 8; z++)
-			if (end.sip6_addr16[z] != 0xffffffff)
+			if (end.sip6_addr16[z] != 0xffff)
 				y = 1;
 		if (!y)
 			x = 1;
@@ -657,6 +712,8 @@ print_help ()
 	printf
 	    ("  -s, --v4split=MASK\t\tSplit the current network into subnets\n");
 	printf ("\t\t\t\tof MASK size.\n");
+	printf ("  -w, --wildcard\t\tDisplay information for a wildcard\n");
+	printf ("\t\t\t\t(inverse mask).\n");
 	printf ("  -x, --classfull-bitmap\tClassfull bitmap.\n");
 	printf ("\n");
 	printf ("IPv6 options:\n");
@@ -712,6 +769,7 @@ print_help ()
 	printf ("  -i\t\tCIDR address information. (default)\n");
 	printf
 	    ("  -s\t\tSplit the current network into subnets of MASK size.\n");
+	printf ("  -w\t\tDisplay information for a wildcard (inverse mask).\n");
 	printf ("  -x\t\tClassfull bitmap.\n");
 	printf ("\n");
 	printf ("IPv6 options:\n");
@@ -756,7 +814,7 @@ print_version ()
 	printf ("%s %s\n", NAME, VERSION);
 	printf ("Written by Simon Ekstrand.\n");
 	printf ("\n");
-	printf ("Copyright (C) 2003 Simon Ekstrand.\n");
+	printf ("Copyright (C) 2003-2005 Simon Ekstrand.\n");
 	printf
 	    ("This is free software; see the source for copying conditions.  There is NO\n");
 	printf
