@@ -113,6 +113,8 @@ out_cmdline (struct if_info *ifarg_cur, int v4args, struct misc_args m_argv4,
 			show_networks_v4 (ifarg_cur, m_argv4.numnets);
 		if ((v4args & V4SPLIT) == V4SPLIT)
 			show_split_networks_v4 (ifarg_cur, m_argv4.splitmask, v4args, m_argv4);
+		if ((v4args & C_WILDCARD) == C_WILDCARD)
+			show_c_wildcard_info_v4 (ifarg_cur);
 		printf ("-\n");
 	}
 
@@ -694,6 +696,7 @@ main (int argc, char *argv[])
 		{"v6rev", no_argument, 0, 'r'},
 		{"split-verbose", no_argument, 0, 'u'},
 		{"resolve", no_argument, 0, 'd'},
+		{"wildcard", no_argument, 0, 'w'},
 		{0, 0, 0, 0}
 	};
 #endif
@@ -735,10 +738,10 @@ main (int argc, char *argv[])
 	 */
 #ifdef HAVE_GETOPT_LONG
 	while ((ch =
-		getopt_long (argc, argv, "abcdehHiI:n:rs:S:tuvVx4:6:", l_o,
+		getopt_long (argc, argv, "abcdehHiI:n:rs:S:tuvVwx4:6:", l_o,
 			     NULL)) != -1) {
 #else
-	while ((ch = getopt (argc, argv, "abcdehHiI:n:rs:S:tuvVx4:6:")) != -1) {
+	while ((ch = getopt (argc, argv, "abcdehHiI:n:rs:S:tuvVwx4:6:")) != -1) {
 #endif
 		switch (ch) {
 		case 'a':
@@ -807,6 +810,9 @@ main (int argc, char *argv[])
 		case 'V':
 			print_version ();
 			return 0;
+		case 'w':
+			v4args = v4args | C_WILDCARD;
+			break;
 		case 'x':
 			v4args = v4args | CF_BITMAP;
 			break;
